@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -282,6 +282,9 @@ if __name__ == '__main__':
     print "????", (res + res).raw, "????"
     print "$$$$", result.Result.fromRowResult(res).raw, "$$$$"
     print '---------------------------------------'
+    print "###", res | None, result.RowResult.new() | res, "###"
+    print '---------------------------------------'
+    print "isinstance: ", isinstance(res, result.ResultProxy), "issubclass: ", issubclass(res.__class__, result.ResultProxy)
     del a
     #print sb.QS(getattr(sb.T, 'user_98')).where((sb.F.status == 1) & (sb.F.a == 'go')).delete()
     #print u.tables(sb.T.good).select('*')
