@@ -2,7 +2,7 @@
 
 __author__ = 'Jefurry <jefurry@qq.com>'
 
-DATABASES = {
+DNS = {
 	'default' : 'mysql://root:@localhost:3306/davos?use_unicode=0&charset=utf8&mincached=20&maxcached=100',
 	'davos' : 'mysql://root:@localhost:3306/davos',
 }
